"""Cipher factory"""

from typing import Type

from luna_cipher.ciphers.aes import AESGCM
from luna_cipher.ciphers.base_cipher import BaseCipher

CIPHERS_MAP = {"aes256-gcm": AESGCM}


def cipherFactory(algorithm: str) -> Type[BaseCipher]:
    """
    Cipher factory

    Args:
        algorithm: data to encrypt
        cipher: cipher args
    Returns:
        cipher instance
    Raises:
        ValueError: if cipher is not supported
    """
    if algorithm not in CIPHERS_MAP:
        raise ValueError(f"Cipher '{algorithm}' is not supported")
    return CIPHERS_MAP[algorithm]
