"""Vault keys bank implementation"""

from luna3.common.exceptions import LunaApiException
from luna3.common.requests import makeRequest

from .base_keys_bank import BaseKeysBank, FailedToGetKey, NoKeyFound, logger


class VaultKVKeysBank(BaseKeysBank):
    """Vault KV keys bank implementation"""

    def __init__(self, url: str, token: str):
        self.url = url
        self.token = token

    async def getKey(self) -> tuple[str, str]:
        """
        Get key from storage

        Returns:
            key and algorithm name

        Raises:
            FailedToGetKey: if failed to get key from source
            NoKeyFound: if no key found at source
        """
        try:
            resp = await makeRequest(
                self.url, "GET", headers={"X-Vault-Token": self.token}, asyncRequest=True, raiseError=True
            )
        except LunaApiException as exc:
            msg = f"Failed to get key, {exc}"
            logger.error(msg)
            raise FailedToGetKey(msg) from exc
        try:
            data = resp.json["data"]["data"]
            return data["key"], data["algorithm"]
        except KeyError as exc:
            raise NoKeyFound("No key found at this path") from exc
